@@ -16,19 +16,21 @@
 import ipaddress
 import os
 import re
-import six
 import string
+from urllib import parse
 
 from operator import xor
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import encodeutils
 from oslo_utils import strutils
-from six.moves.urllib import parse
 import webob
+from webob import exc
 
 from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import versioned_method
+from manila.common import constants
+from manila.db import api as db_api
 from manila import exception
 from manila.i18n import _
 from manila import policy
@@ -66,7 +68,7 @@ def validate_key_names(key_names_list):
 
 
 def get_pagination_params(request):
-    """Return marker, limit tuple from request.
+    """Return marker, limit, offset tuple from request.
 
     :param request: `wsgi.Request` possibly containing 'marker' and 'limit'
                     GET variables. 'marker' is the id of the last element
@@ -82,11 +84,18 @@ def get_pagination_params(request):
         params['limit'] = _get_limit_param(request)
     if 'marker' in request.GET:
         params['marker'] = _get_marker_param(request)
+    if 'offset' in request.GET:
+        params['offset'] = _get_offset_param(request)
     return params
 
 
 def _get_limit_param(request):
-    """Extract integer limit from request or fail."""
+    """Extract integer limit from request or fail.
+
+    Defaults to max_limit if not present and returns max_limit if present
+   'limit' is greater than max_limit.
+    """
+    max_limit = CONF.osapi_max_limit
     try:
         limit = int(request.GET['limit'])
     except ValueError:
@@ -95,6 +104,7 @@ def _get_limit_param(request):
     if limit < 0:
         msg = _('limit param must be positive')
         raise webob.exc.HTTPBadRequest(explanation=msg)
+    limit = min(limit, max_limit)
     return limit
 
 
@@ -103,6 +113,31 @@ def _get_marker_param(request):
     return request.GET['marker']
 
 
+def _get_offset_param(request):
+    """Extract offset id from request's dictionary (defaults to 0) or fail."""
+    offset = request.GET['offset']
+    return _validate_integer(offset,
+                             'offset',
+                             0,
+                             constants.DB_MAX_INT)
+
+
+def _validate_integer(value, name, min_value=None, max_value=None):
+    """Make sure that value is a valid integer, potentially within range.
+
+    :param value: the value of the integer
+    :param name: the name of the integer
+    :param min_value: the min_length of the integer
+    :param max_value: the max_length of the integer
+    :return: integer
+    """
+    try:
+        value = strutils.validate_integer(value, name, min_value, max_value)
+        return value
+    except ValueError as e:
+        raise webob.exc.HTTPBadRequest(explanation=str(e))
+
+
 def _validate_pagination_query(request, max_limit=CONF.osapi_max_limit):
     """Validate the given request query and return limit and offset."""
 
@@ -148,6 +183,25 @@ def limited(items, request, max_limit=CONF.osapi_max_limit):
     return items[offset:range_end]
 
 
+def get_sort_params(params, default_key='created_at', default_dir='desc'):
+    """Retrieves sort key/direction parameters.
+
+    Processes the parameters to get the 'sort_key' and 'sort_dir' parameter
+    values.
+
+    :param params: webob.multidict of request parameters (from
+                   manila.api.openstack.wsgi.Request.params)
+    :param default_key: default sort key value, will return if no
+                        sort key are supplied
+    :param default_dir: default sort dir value, will return if no
+                        sort dir are supplied
+    :returns: value of sort key, value of sort dir
+    """
+    sort_key = params.pop('sort_key', default_key)
+    sort_dir = params.pop('sort_dir', default_dir)
+    return sort_key, sort_dir
+
+
 def remove_version_from_href(href):
     """Removes the first api version from the href.
 
@@ -201,12 +255,56 @@ def check_net_id_and_subnet_id(body):
         raise webob.exc.HTTPBadRequest(explanation=msg)
 
 
+def check_share_network_is_active(share_network):
+    network_status = share_network.get('status')
+    if network_status != constants.STATUS_NETWORK_ACTIVE:
+        msg = _("The share network %(id)s used isn't in an 'active' state. "
+                "Current status is %(status)s. The action may be retried "
+                "after the share network has changed its state.") % {
+            'id': share_network['id'],
+            'status': share_network.get('status'),
+        }
+        raise webob.exc.HTTPBadRequest(explanation=msg)
+
+
+def parse_is_public(is_public):
+    """Parse is_public into something usable.
+
+    :returns:
+        - True: API should list public share group types only
+        - False: API should list private share group types only
+        - None: API should list both public and private share group types
+    """
+    if is_public is None:
+        # preserve default value of showing only public types
+        return True
+    elif str(is_public).lower() == "all":
+        return None
+    else:
+        try:
+            return strutils.bool_from_string(is_public, strict=True)
+        except ValueError:
+            msg = _('Invalid is_public filter [%s]') % is_public
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+
+
 class ViewBuilder(object):
     """Model API responses as dictionaries."""
 
     _collection_name = None
     _detail_version_modifiers = []
 
+    def _get_project_id(self, request):
+        project_id = request.environ["manila.context"].project_id
+        if '/v1/' in request.url:
+            # project_ids are mandatory in v1 URLs
+            return project_id
+        elif project_id and ("/v2/%s" % project_id in request.url):
+            # project_ids are not mandatory within v2 URLs, but links need
+            # to include them if the request does.
+            return project_id
+        return ''
+
     def _get_links(self, request, identifier):
         return [{"rel": "self",
                  "href": self._get_href_link(request, identifier), },
@@ -220,7 +318,7 @@ class ViewBuilder(object):
         prefix = self._update_link_prefix(request.application_url,
                                           CONF.osapi_share_base_URL)
         url = os.path.join(prefix,
-                           request.environ["manila.context"].project_id,
+                           self._get_project_id(request),
                            self._collection_name)
         return "%s?%s" % (url, dict_to_query_str(params))
 
@@ -229,7 +327,7 @@ class ViewBuilder(object):
         prefix = self._update_link_prefix(request.application_url,
                                           CONF.osapi_share_base_URL)
         return os.path.join(prefix,
-                            request.environ["manila.context"].project_id,
+                            self._get_project_id(request),
                             self._collection_name,
                             str(identifier))
 
@@ -239,7 +337,7 @@ class ViewBuilder(object):
         base_url = self._update_link_prefix(base_url,
                                             CONF.osapi_share_base_URL)
         return os.path.join(base_url,
-                            request.environ["manila.context"].project_id,
+                            self._get_project_id(request),
                             self._collection_name,
                             str(identifier))
 
@@ -334,6 +432,7 @@ def validate_common_name(access):
         exc_str = _('Invalid CN (common name). Must be 1-64 chars long.')
         raise webob.exc.HTTPBadRequest(explanation=exc_str)
 
+
 '''
 for the reference specification for AD usernames, reference below links:
 
@@ -343,8 +442,8 @@ for the reference specification for AD usernames, reference below links:
 
 
 def validate_username(access):
-    sole_periods_spaces_re = '[\s|\.]+$'
-    valid_username_re = '.[^\"\/\\\[\]\:\;\|\=\,\+\*\?\<\>]{3,254}$'
+    sole_periods_spaces_re = r'[\s|\.]+$'
+    valid_username_re = r'.[^\"\/\\\[\]\:\;\|\=\,\+\*\?\<\>]{3,254}$'
     username = access
 
     if re.match(sole_periods_spaces_re, username):
@@ -355,7 +454,7 @@ def validate_username(access):
     if not re.match(valid_username_re, username):
         exc_str = ('Invalid user or group name. Must be 4-255 characters '
                    'and consist of alphanumeric characters and '
-                   'exclude special characters "/\[]:;|=,+*?<>')
+                   'exclude special characters "/\\[]:;|=,+*?<>')
         raise webob.exc.HTTPBadRequest(explanation=exc_str)
 
 
@@ -385,7 +484,7 @@ def validate_ip(access_to, enable_ipv6):
             validator = ipaddress.ip_network
         else:
             validator = ipaddress.IPv4Network
-        validator(six.text_type(access_to))
+        validator(str(access_to))
     except ValueError as error:
         err_msg = encodeutils.exception_to_unicode(error)
         raise webob.exc.HTTPBadRequest(explanation=err_msg)
@@ -417,6 +516,22 @@ def validate_access(*args, **kwargs):
         raise webob.exc.HTTPBadRequest(explanation=exc_str)
 
 
+def validate_integer(value, name, min_value=None, max_value=None):
+    """Make sure that value is a valid integer, potentially within range.
+
+    :param value: the value of the integer
+    :param name: the name of the integer
+    :param min_length: the min_length of the integer
+    :param max_length: the max_length of the integer
+    :returns: integer
+    """
+    try:
+        value = strutils.validate_integer(value, name, min_value, max_value)
+        return value
+    except ValueError as e:
+        raise webob.exc.HTTPBadRequest(explanation=str(e))
+
+
 def validate_public_share_policy(context, api_params, api='create'):
     """Validates if policy allows is_public parameter to be set to True.
 
@@ -437,7 +552,7 @@ def validate_public_share_policy(context, api_params, api='create'):
         api_params['is_public'] = strutils.bool_from_string(
             api_params['is_public'], strict=True)
     except ValueError as e:
-        raise exception.InvalidParameterValue(six.text_type(e))
+        raise exception.InvalidParameterValue(str(e))
 
     public_shares_allowed = policy.check_policy(
         context, 'share', policy_to_check, do_raise=False)
@@ -447,3 +562,78 @@ def validate_public_share_policy(context, api_params, api='create'):
         raise exception.NotAuthorized(message=message)
 
     return api_params
+
+
+def _get_existing_subnets(context, share_network_id, az):
+    """Return any existing subnets in the requested AZ.
+
+    If az is None, the method will search for an existent default subnet.
+    """
+    if az is None:
+        return db_api.share_network_subnet_get_default_subnets(
+            context, share_network_id)
+
+    return (
+        db_api.share_network_subnets_get_all_by_availability_zone_id(
+            context, share_network_id, az,
+            fallback_to_default=False)
+    )
+
+
+def validate_subnet_create(context, share_network_id, data,
+                           multiple_subnet_support):
+
+    check_net_id_and_subnet_id(data)
+    try:
+        share_network = db_api.share_network_get(
+            context, share_network_id)
+    except exception.ShareNetworkNotFound as e:
+        raise exc.HTTPNotFound(explanation=e.msg)
+
+    availability_zone = data.pop('availability_zone', None)
+    subnet_az = {}
+    if availability_zone:
+        try:
+            subnet_az = db_api.availability_zone_get(context,
+                                                     availability_zone)
+        except exception.AvailabilityZoneNotFound:
+            msg = _("The provided availability zone %s does not "
+                    "exist.") % availability_zone
+            raise exc.HTTPBadRequest(explanation=msg)
+    data['availability_zone_id'] = subnet_az.get('id')
+
+    existing_subnets = _get_existing_subnets(
+        context, share_network_id, data['availability_zone_id'])
+    if existing_subnets and not multiple_subnet_support:
+        msg = ("Another share network subnet was found in the "
+               "specified availability zone. Only one share network "
+               "subnet is allowed per availability zone for share "
+               "network %s." % share_network_id)
+        raise exc.HTTPConflict(explanation=msg)
+
+    return share_network, existing_subnets
+
+
+def _check_metadata_properties(metadata=None):
+    if not metadata:
+        metadata = {}
+
+    for k, v in metadata.items():
+        if not k:
+            msg = _("Metadata property key is blank.")
+            LOG.warning(msg)
+            raise exception.InvalidMetadata(message=msg)
+        if len(k) > 255:
+            msg = _("Metadata property key is "
+                    "greater than 255 characters.")
+            LOG.warning(msg)
+            raise exception.InvalidMetadataSize(message=msg)
+        if not v:
+            msg = _("Metadata property value is blank.")
+            LOG.warning(msg)
+            raise exception.InvalidMetadata(message=msg)
+        if len(v) > 1023:
+            msg = _("Metadata property value is "
+                    "greater than 1023 characters.")
+            LOG.warning(msg)
+            raise exception.InvalidMetadataSize(message=msg)
