@@ -777,9 +777,9 @@ def security_service_update(context, id, values):
     return IMPL.security_service_update(context, id, values)
 
 
-def security_service_get(context, id):
+def security_service_get(context, id, **kwargs):
     """Get security service DB record."""
-    return IMPL.security_service_get(context, id)
+    return IMPL.security_service_get(context, id, **kwargs)
 
 
 def security_service_get_all(context):
@@ -1095,13 +1095,20 @@ def share_server_search_by_identifier(context, identifier, session=None):
 
 def share_server_get_all_by_host_and_share_subnet_valid(context, host,
                                                         share_subnet_id,
-                                                        server_status=None,
                                                         session=None):
     """Get share server DB records by host and share net not error."""
     return IMPL.share_server_get_all_by_host_and_share_subnet_valid(
         context, host, share_subnet_id, session=session)
 
 
+def share_server_get_all_by_host_and_share_subnet(context, host,
+                                                  share_subnet_id,
+                                                  session=None):
+    """Get share server DB records by host and share net."""
+    return IMPL.share_server_get_all_by_host_and_share_subnet(
+        context, host, share_subnet_id, session=session)
+
+
 def share_server_get_all(context):
     """Get all share server DB records."""
     return IMPL.share_server_get_all(context)
