@@ -212,6 +212,12 @@ deprecated_share_snapshot_update = policy.DeprecatedRule(
     deprecated_since=versionutils.deprecated.WALLABY
 )
 
+deprecated_update_admin_only_metadata = policy.DeprecatedRule(
+    name=BASE_POLICY_NAME % 'update_admin_only_metadata',
+    check_str=base.RULE_ADMIN_API,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since="YOGA"
+)
 
 shares_policies = [
     policy.DocumentedRuleDefault(
@@ -310,6 +316,30 @@ shares_policies = [
         ],
         deprecated_rule=deprecated_share_delete
     ),
+    policy.DocumentedRuleDefault(
+        name=BASE_POLICY_NAME % 'soft_delete',
+        check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
+        scope_types=['system', 'project'],
+        description="Soft Delete a share.",
+        operations=[
+            {
+                'method': 'POST',
+                'path': '/shares/{share_id}/action',
+            }
+        ],
+    ),
+    policy.DocumentedRuleDefault(
+        name=BASE_POLICY_NAME % 'restore',
+        check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
+        scope_types=['system', 'project'],
+        description="Restore a share.",
+        operations=[
+            {
+                'method': 'POST',
+                'path': '/shares/{share_id}/action',
+            }
+        ],
+    ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'force_delete',
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_ADMIN,
@@ -568,12 +598,20 @@ shares_policies = [
         name=BASE_POLICY_NAME % 'update_share_metadata',
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
         scope_types=['system', 'project'],
-        description=("Update share metadata."),
+        description="Update share metadata.",
         operations=[
             {
                 'method': 'PUT',
                 'path': '/shares/{share_id}/metadata',
-            }
+            },
+            {
+                'method': 'POST',
+                'path': '/shares/{share_id}/metadata/{key}',
+            },
+            {
+                'method': 'POST',
+                'path': '/shares/{share_id}/metadata',
+            },
         ],
         deprecated_rule=deprecated_share_update_metadata
     ),
@@ -581,7 +619,7 @@ shares_policies = [
         name=BASE_POLICY_NAME % 'delete_share_metadata',
         check_str=base.SYSTEM_ADMIN_OR_PROJECT_MEMBER,
         scope_types=['system', 'project'],
-        description=("Delete share metadata."),
+        description="Delete share metadata.",
         operations=[
             {
                 'method': 'DELETE',
@@ -594,11 +632,15 @@ shares_policies = [
         name=BASE_POLICY_NAME % 'get_share_metadata',
         check_str=base.SYSTEM_OR_PROJECT_READER,
         scope_types=['system', 'project'],
-        description=("Get share metadata."),
+        description="Get share metadata.",
         operations=[
             {
                 'method': 'GET',
                 'path': '/shares/{share_id}/metadata',
+            },
+            {
+                'method': 'GET',
+                'path': '/shares/{share_id}/metadata/{key}',
             }
         ],
         deprecated_rule=deprecated_share_get_metadata
@@ -648,6 +690,21 @@ base_snapshot_policies = [
         ],
         deprecated_rule=deprecated_share_snapshot_update
     ),
+    policy.DocumentedRuleDefault(
+        name=BASE_POLICY_NAME % 'update_admin_only_metadata',
+        check_str=base.SYSTEM_ADMIN_OR_PROJECT_ADMIN,
+        scope_types=['system', 'project'],
+        description=(
+            "Update metadata items that are considered \"admin only\" "
+            "by the service."),
+        operations=[
+            {
+                'method': 'PUT',
+                'path': '/shares/{share_id}/metadata',
+            }
+        ],
+        deprecated_rule=deprecated_update_admin_only_metadata
+    ),
 ]
 
 
