@@ -67,6 +67,9 @@ class HitachiHSPDriver(driver.ShareDriver):
         LOG.debug("Updating Backend Capability Information - Hitachi HSP.")
 
         reserved = self.configuration.safe_get('reserved_share_percentage')
+        reserved_snapshot = (self.configuration.safe_get(
+            'reserved_share_from_snapshot_percentage') or
+            self.configuration.safe_get('reserved_share_percentage'))
         max_over_subscription_ratio = self.configuration.safe_get(
             'max_over_subscription_ratio')
         hsp_cluster = self.hsp.get_cluster()
@@ -81,6 +84,7 @@ class HitachiHSPDriver(driver.ShareDriver):
             'storage_protocol': 'NFS',
             'pools': [{
                 'reserved_percentage': reserved,
+                'reserved_snapshot_percentage': reserved_snapshot,
                 'pool_name': 'HSP',
                 'thin_provisioning': True,
                 'total_capacity_gb': total_space / units.Gi,
