@@ -16,11 +16,8 @@
 """Abstract base class to work with share."""
 import abc
 
-import six
 
-
-@six.add_metaclass(abc.ABCMeta)
-class HuaweiBase(object):
+class HuaweiBase(metaclass=abc.ABCMeta):
     """Interface to work with share."""
 
     def __init__(self, configuration):
@@ -66,7 +63,7 @@ class HuaweiBase(object):
 
     @abc.abstractmethod
     def create_share_from_snapshot(self, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Create share from snapshot."""
 
     @abc.abstractmethod
