@@ -85,6 +85,13 @@ def get_client_for_backend(backend_name, vserver_name=None):
     return client
 
 
+def get_client_for_host(host):
+    """Returns a cluster client to the desired host."""
+    backend_name = share_utils.extract_host(host, level='backend_name')
+    client = get_client_for_backend(backend_name)
+    return client
+
+
 class DataMotionSession(object):
 
     def _get_backend_volume_name(self, config, share_obj):
@@ -160,11 +167,13 @@ class DataMotionSession(object):
                                 'last-transfer-end-timestamp'])
         return snapmirrors
 
-    def create_snapmirror(self, source_share_obj, dest_share_obj):
+    def create_snapmirror(self, source_share_obj, dest_share_obj,
+                          relationship_type, mount=False):
         """Sets up a SnapMirror relationship between two volumes.
 
-        1. Create SnapMirror relationship
-        2. Initialize data transfer asynchronously
+        1. Create SnapMirror relationship.
+        2. Initialize data transfer asynchronously.
+        3. Mount destination volume if requested.
         """
         dest_volume_name, dest_vserver, dest_backend = (
             self.get_backend_info_for_share(dest_share_obj))
@@ -180,6 +189,7 @@ class DataMotionSession(object):
                                           src_volume_name,
                                           dest_vserver,
                                           dest_volume_name,
+                                          relationship_type,
                                           schedule='hourly')
 
         # 2. Initialize async transfer of the initial data
@@ -188,8 +198,15 @@ class DataMotionSession(object):
                                               dest_vserver,
                                               dest_volume_name)
 
+        # 3. Mount the destination volume and create a junction path
+        if mount:
+            replica_config = get_backend_configuration(dest_backend)
+            self.wait_for_mount_replica(
+                dest_client, dest_volume_name,
+                timeout=replica_config.netapp_mount_replica_timeout)
+
     def delete_snapmirror(self, source_share_obj, dest_share_obj,
-                          release=True):
+                          release=True, relationship_info_only=False):
         """Ensures all information about a SnapMirror relationship is removed.
 
         1. Abort snapmirror
@@ -236,21 +253,16 @@ class DataMotionSession(object):
                                                     vserver_name=src_vserver)
             except Exception:
                 src_client = None
+
             # 3. Cleanup SnapMirror relationship on source
-            try:
-                if src_client:
-                    src_client.release_snapmirror_vol(src_vserver,
-                                                      src_volume_name,
-                                                      dest_vserver,
-                                                      dest_volume_name)
-            except netapp_api.NaApiError as e:
-                with excutils.save_and_reraise_exception() as exc_context:
-                    if (e.code == netapp_api.EOBJECTNOTFOUND or
-                            e.code == netapp_api.ESOURCE_IS_DIFFERENT or
-                            "(entry doesn't exist)" in e.message):
-                        # Handle the case where the snapmirror is already
-                        # cleaned up
-                        exc_context.reraise = False
+            if src_client:
+                src_config = get_backend_configuration(src_backend)
+                release_timeout = (
+                    src_config.netapp_snapmirror_release_timeout)
+                self.wait_for_snapmirror_release_vol(
+                    src_vserver, dest_vserver, src_volume_name,
+                    dest_volume_name, relationship_info_only, src_client,
+                    timeout=release_timeout)
 
     def update_snapmirror(self, source_share_obj, dest_share_obj):
         """Schedule a snapmirror update to happen on the backend."""
@@ -282,8 +294,10 @@ class DataMotionSession(object):
         config = get_backend_configuration(dest_backend)
         retries = config.netapp_snapmirror_quiesce_timeout / 5
 
-        @utils.retry(exception.ReplicationException, interval=5,
-                     retries=retries, backoff_rate=1)
+        @utils.retry(retry_param=exception.ReplicationException,
+                     interval=5,
+                     retries=retries,
+                     backoff_rate=1)
         def wait_for_quiesced():
             snapmirror = dest_client.get_snapmirrors_svm(
                 source_vserver=source_vserver, dest_vserver=dest_vserver,
@@ -318,8 +332,10 @@ class DataMotionSession(object):
         config = get_backend_configuration(dest_backend)
         retries = config.netapp_snapmirror_quiesce_timeout / 5
 
-        @utils.retry(exception.ReplicationException, interval=5,
-                     retries=retries, backoff_rate=1)
+        @utils.retry(retry_param=exception.ReplicationException,
+                     interval=5,
+                     retries=retries,
+                     backoff_rate=1)
         def wait_for_quiesced():
             snapmirror = dest_client.get_snapmirrors(
                 source_vserver=src_vserver, dest_vserver=dest_vserver,
@@ -400,7 +416,8 @@ class DataMotionSession(object):
 
     def change_snapmirror_source(self, replica,
                                  orig_source_replica,
-                                 new_source_replica, replica_list):
+                                 new_source_replica, replica_list,
+                                 is_flexgroup=False):
         """Creates SnapMirror relationship from the new source to destination.
 
         1. Delete all snapmirrors involving the replica, but maintain
@@ -424,11 +441,16 @@ class DataMotionSession(object):
             if other_replica['id'] == replica['id']:
                 continue
 
-            # We need to delete ALL snapmirror relationships
-            # involving this replica but do not remove snapmirror metadata
-            # so that the new snapmirror relationship is efficient.
-            self.delete_snapmirror(other_replica, replica, release=False)
-            self.delete_snapmirror(replica, other_replica, release=False)
+            # deletes all snapmirror relationships involving this replica to
+            # ensure new relation can be set. For efficient snapmirror, it
+            # does not remove the snapshots, only releasing the relationship
+            # info if FlexGroup volume.
+            self.delete_snapmirror(other_replica, replica,
+                                   release=is_flexgroup,
+                                   relationship_info_only=is_flexgroup)
+            self.delete_snapmirror(replica, other_replica,
+                                   release=is_flexgroup,
+                                   relationship_info_only=is_flexgroup)
 
         # 2. vserver operations when driver handles share servers
         replica_config = get_backend_configuration(replica_backend)
@@ -452,11 +474,14 @@ class DataMotionSession(object):
 
         # 3. create
         # TODO(ameade): Update the schedule if needed.
+        relationship_type = na_utils.get_relationship_type(is_flexgroup)
         replica_client.create_snapmirror_vol(new_src_vserver,
                                              new_src_volume_name,
                                              replica_vserver,
                                              replica_volume_name,
+                                             relationship_type,
                                              schedule='hourly')
+
         # 4. resync
         replica_client.resync_snapmirror_vol(new_src_vserver,
                                              new_src_volume_name,
@@ -613,8 +638,10 @@ class DataMotionSession(object):
         interval = 10
         retries = (timeout / interval or 1)
 
-        @utils.retry(exception.VserverNotReady, interval=interval,
-                     retries=retries, backoff_rate=1)
+        @utils.retry(retry_param=exception.VserverNotReady,
+                     interval=interval,
+                     retries=retries,
+                     backoff_rate=1)
         def wait_for_state():
             vserver_info = client.get_vserver_info(vserver_name)
             if vserver_info.get('subtype') != 'default':
@@ -686,8 +713,10 @@ class DataMotionSession(object):
         if subtype:
             expected['subtype'] = subtype
 
-        @utils.retry(exception.VserverNotReady, interval=interval,
-                     retries=retries, backoff_rate=1)
+        @utils.retry(retry_param=exception.VserverNotReady,
+                     interval=interval,
+                     retries=retries,
+                     backoff_rate=1)
         def wait_for_state():
             vserver_info = client.get_vserver_info(vserver_name)
             if not all(item in vserver_info.items() for
@@ -705,8 +734,10 @@ class DataMotionSession(object):
         interval = 10
         retries = (timeout / interval or 1)
 
-        @utils.retry(exception.NetAppException, interval=interval,
-                     retries=retries, backoff_rate=1)
+        @utils.retry(retry_param=exception.NetAppException,
+                     interval=interval,
+                     retries=retries,
+                     backoff_rate=1)
         def release_snapmirror():
             snapmirrors = src_client.get_snapmirror_destinations_svm(
                 source_vserver=source_vserver, dest_vserver=dest_vserver)
@@ -733,3 +764,77 @@ class DataMotionSession(object):
             msg = _("Unable to release the snapmirror from source vserver %s. "
                     "Retries exhausted. Aborting") % source_vserver
             raise exception.NetAppException(message=msg)
+
+    def wait_for_mount_replica(self, vserver_client, share_name, timeout=300):
+        """Mount a replica share that is waiting for snapmirror initialize."""
+
+        interval = 10
+        retries = (timeout // interval or 1)
+
+        @utils.retry(exception.ShareBusyException, interval=interval,
+                     retries=retries, backoff_rate=1)
+        def try_mount_volume():
+            try:
+                vserver_client.mount_volume(share_name)
+            except netapp_api.NaApiError as e:
+                undergoing_snap_init = 'snapmirror initialize'
+                msg_args = {'name': share_name}
+                if (e.code == netapp_api.EAPIERROR and
+                        undergoing_snap_init in e.message):
+                    msg = _('The share %(name)s is undergoing a snapmirror '
+                            'initialize. Will retry the operation.') % msg_args
+                    LOG.warning(msg)
+                    raise exception.ShareBusyException(reason=msg)
+                else:
+                    msg = _("Unable to perform mount operation for the share "
+                            "%(name)s. Caught an unexpected error. Not "
+                            "retrying.") % msg_args
+                    raise exception.NetAppException(message=msg)
+
+        try:
+            try_mount_volume()
+        except exception.ShareBusyException:
+            msg_args = {'name': share_name}
+            msg = _("Unable to perform mount operation for the share %(name)s "
+                    "because a snapmirror initialize operation is still in "
+                    "progress. Retries exhausted. Not retrying.") % msg_args
+            raise exception.NetAppException(message=msg)
+
+    def wait_for_snapmirror_release_vol(self, src_vserver, dest_vserver,
+                                        src_volume_name, dest_volume_name,
+                                        relationship_info_only, src_client,
+                                        timeout=300):
+        interval = 10
+        retries = (timeout / interval or 1)
+
+        @utils.retry(exception.NetAppException, interval=interval,
+                     retries=retries, backoff_rate=1)
+        def release_snapmirror():
+            snapmirrors = src_client.get_snapmirror_destinations(
+                source_vserver=src_vserver, dest_vserver=dest_vserver,
+                source_volume=src_volume_name, dest_volume=dest_volume_name)
+            if not snapmirrors:
+                LOG.debug("No snapmirrors to be released in source volume.")
+            else:
+                try:
+                    src_client.release_snapmirror_vol(
+                        src_vserver, src_volume_name, dest_vserver,
+                        dest_volume_name,
+                        relationship_info_only=relationship_info_only)
+                except netapp_api.NaApiError as e:
+                    if (e.code == netapp_api.EOBJECTNOTFOUND or
+                            e.code == netapp_api.ESOURCE_IS_DIFFERENT or
+                            "(entry doesn't exist)" in e.message):
+                        LOG.debug('Snapmirror relationship does not exist '
+                                  'anymore.')
+
+                msg = _('Snapmirror release sent to source volume. Waiting '
+                        'until it has been released.')
+                raise exception.NetAppException(vserver=msg)
+
+        try:
+            release_snapmirror()
+        except exception.NetAppException:
+            msg = _("Unable to release the snapmirror from source volume %s. "
+                    "Retries exhausted. Aborting") % src_volume_name
+            raise exception.NetAppException(message=msg)
