@@ -26,7 +26,6 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import importutils
 from oslo_utils import netutils
-import six
 
 from manila.common import constants as const
 from manila import compute
@@ -49,7 +48,7 @@ share_servers_handling_mode_opts = [
              "creation. Only used if driver_handles_share_servers=True."),
     cfg.StrOpt(
         "service_instance_name_template",
-        default="manila_service_instance_%s",
+        default="%s",
         help="Name of service instance. "
              "Only used if driver_handles_share_servers=True."),
     cfg.StrOpt(
@@ -306,7 +305,7 @@ class ServiceInstanceManager(object):
 
     def _get_service_instance_name(self, share_server_id):
         """Returns service vms name."""
-        if self.driver_config:
+        if self.driver_config and self.driver_config.config_group:
             # Make service instance name unique for multibackend installation
             name = "%s_%s" % (self.driver_config.config_group, share_server_id)
         else:
@@ -320,7 +319,7 @@ class ServiceInstanceManager(object):
             msg = _("Failed to get service instance IP address. "
                     "Service network name is '%(net_name)s' "
                     "and provided data are '%(data)s'.")
-            msg = msg % {'net_name': net_name, 'data': six.text_type(server)}
+            msg = msg % {'net_name': net_name, 'data': str(server)}
             raise exception.ServiceInstanceException(msg)
         return net_ips[0]
 
@@ -450,7 +449,8 @@ class ServiceInstanceManager(object):
         :returns: dict with service instance details
         :raises: exception.ServiceInstanceException
         """
-        instance_name = network_info['server_id']
+        instance_name = self._get_service_instance_name(
+            network_info['server_id'])
         server = self._create_service_instance(
             context, instance_name, network_info)
         instance_details = self._get_new_instance_details(server)
@@ -724,8 +724,7 @@ class ServiceInstanceManager(object):
                                        soft_reboot)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseNetworkhelper(object):
+class BaseNetworkhelper(metaclass=abc.ABCMeta):
 
     @abc.abstractproperty
     def NAME(self):
@@ -953,7 +952,7 @@ class NeutronNetworkHelper(BaseNetworkhelper):
             self.get_config_option("service_network_cidr"))
         division_mask = self.get_config_option("service_network_division_mask")
         for subnet in serv_cidr.subnet(division_mask):
-            cidr = six.text_type(subnet.cidr)
+            cidr = str(subnet.cidr)
             if cidr not in used_cidrs:
                 return cidr
         else:
