@@ -13,8 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-from six.moves.urllib import parse
+from unittest import mock
+from urllib import parse
+
+import ddt
 import webob
 
 from manila.api.v1 import security_service
@@ -25,6 +27,7 @@ from manila import test
 from manila.tests.api import fakes
 
 
+@ddt.ddt
 class ShareApiTest(test.TestCase):
     """Share Api Test."""
     def setUp(self):
@@ -81,6 +84,21 @@ class ShareApiTest(test.TestCase):
             }, ]
         }
 
+        self.fake_share_network_list_with_share_servers = [{
+            'id': 'fake_sn_id',
+            'share_network_subnets': [{
+                'id': 'fake_sns_id',
+                'share_servers': [{'id': 'fake_ss_id'}]
+            }]
+        }]
+        self.fake_share_network_list_without_share_servers = [{
+            'id': 'fake_sn_id',
+            'share_network_subnets': [{
+                'id': 'fake_sns_id',
+                'share_servers': []
+            }]
+        }]
+
     def _stop_started_patcher(self, patcher):
         if hasattr(patcher, 'is_local'):
             patcher.stop()
@@ -163,10 +181,11 @@ class ShareApiTest(test.TestCase):
         self.mock_object(security_service.policy, 'check_policy')
         db.security_service_get = mock.Mock(return_value=new)
         db.security_service_update = mock.Mock(return_value=updated)
+        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service = mock.Mock(
             return_value=[{
                 'id': 'fake_id',
-                'share_servers': 'fake_share_server'
+                'share_network_subnets': [fake_sns]
             }])
         body = {"security_service": {"name": "new"}}
         req = fakes.HTTPRequest.blank('/security_service/1')
@@ -187,10 +206,11 @@ class ShareApiTest(test.TestCase):
         self.mock_object(security_service.policy, 'check_policy')
         db.security_service_get = mock.Mock(return_value=new)
         db.security_service_update = mock.Mock(return_value=updated)
+        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service = mock.Mock(
             return_value=[{
                 'id': 'fake_id',
-                'share_servers': 'fake_share_server'
+                'share_network_subnets': [fake_sns]
             }])
         body = {"security_service": {"description": "new"}}
         req = fakes.HTTPRequest.blank('/security_service/1')
@@ -209,8 +229,9 @@ class ShareApiTest(test.TestCase):
                        mock.Mock())
     def test_security_service_update_invalid_keys_sh_server_exists(self):
         self.mock_object(security_service.policy, 'check_policy')
+        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service.return_value = [
-            {'id': 'fake_id', 'share_servers': 'fake_share_servers'},
+            {'id': 'fake_id', 'share_network_subnets': [fake_sns]},
         ]
         db.security_service_get.return_value = self.ss_active_directory.copy()
         body = {'security_service': {'user_id': 'new_user'}}
@@ -234,8 +255,9 @@ class ShareApiTest(test.TestCase):
                        mock.Mock())
     def test_security_service_update_valid_keys_sh_server_exists(self):
         self.mock_object(security_service.policy, 'check_policy')
+        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service.return_value = [
-            {'id': 'fake_id', 'share_servers': 'fake_share_servers'},
+            {'id': 'fake_id', 'share_network_subnets': [fake_sns]},
         ]
         old = self.ss_active_directory.copy()
         updated = self.ss_active_directory.copy()
@@ -265,6 +287,36 @@ class ShareApiTest(test.TestCase):
                       security_service.RESOURCE_NAME, 'update', old)
         ])
 
+    @mock.patch.object(db, 'security_service_get', mock.Mock())
+    def test_security_service_update_has_share_servers(self):
+        db.security_service_get = mock.Mock()
+        self.mock_object(
+            self.controller, '_share_servers_dependent_on_sn_exist',
+            mock.Mock(return_value=True))
+        body = {"security_service": {"type": "ldap"}}
+
+        req = fakes.HTTPRequest.blank('/security_services/1')
+        self.assertRaises(webob.exc.HTTPForbidden,
+                          self.controller.update,
+                          req,
+                          1,
+                          body)
+
+    @ddt.data(True, False)
+    def test_security_service_update_share_server_dependent_exists(self,
+                                                                   expected):
+        req = fakes.HTTPRequest.blank('/security_services/1')
+        context = req.environ['manila.context']
+        db.security_service_get = mock.Mock()
+        network = (self.fake_share_network_list_with_share_servers if expected
+                   else self.fake_share_network_list_without_share_servers)
+        db.share_network_get_all_by_security_service = mock.Mock(
+            return_value=network)
+
+        result = self.controller._share_servers_dependent_on_sn_exist(
+            context, 'fake_id')
+        self.assertEqual(expected, result)
+
     def test_security_service_list(self):
         db.security_service_get_all_by_project = mock.Mock(
             return_value=[self.ss_active_directory.copy()])
@@ -302,18 +354,35 @@ class ShareApiTest(test.TestCase):
         db.security_service_get_all.assert_called_once_with(
             req.environ['manila.context'])
 
-    @mock.patch.object(db, 'security_service_get_all', mock.Mock())
+    @mock.patch.object(db, 'security_service_get_all_by_project', mock.Mock())
     def test_security_services_list_all_tenants_non_admin_context(self):
-        self.check_policy_patcher.stop()
-        db.security_service_get_all.return_value = [
-            self.ss_active_directory,
-            self.ss_ldap,
-        ]
+        db.security_service_get_all_by_project.return_value = []
         req = fakes.HTTPRequest.blank(
             '/security-services?all_tenants=1')
-        self.assertRaises(exception.PolicyNotAuthorized, self.controller.index,
-                          req)
-        self.assertFalse(db.security_service_get_all.called)
+        fake_context = req.environ['manila.context']
+        self.controller.index(req)
+        db.security_service_get_all_by_project.assert_called_once_with(
+            fake_context, fake_context.project_id
+        )
+
+    @mock.patch.object(db, 'security_service_get_all', mock.Mock())
+    def test_security_services_list_all_tenants_with_invalid_value(self):
+        req = fakes.HTTPRequest.blank(
+            '/security-services?all_tenants=nerd',
+            use_admin_context=True)
+        self.assertRaises(exception.InvalidInput, self.controller.index, req)
+
+    @mock.patch.object(db, 'security_service_get_all_by_project', mock.Mock())
+    def test_security_services_list_all_tenants_with_value_zero(self):
+        db.security_service_get_all_by_project.return_value = []
+        req = fakes.HTTPRequest.blank(
+            '/security-services?all_tenants=0',
+            use_admin_context=True)
+        res_dict = self.controller.index(req)
+        self.assertEqual({'security_services': []}, res_dict)
+        db.security_service_get_all_by_project.assert_called_once_with(
+            req.environ['manila.context'],
+            req.environ['manila.context'].project_id)
 
     @mock.patch.object(db, 'security_service_get_all_by_project', mock.Mock())
     def test_security_services_list_admin_context_invalid_opts(self):
