@@ -46,6 +46,7 @@ SERVICE_STATES_NO_POOLS = {
     'host1': dict(share_backend_name='AAA',
                   total_capacity_gb=512, free_capacity_gb=200,
                   timestamp=None, reserved_percentage=0,
+                  reserved_snapshot_percentage=0,
                   provisioned_capacity_gb=312,
                   max_over_subscription_ratio=1.0,
                   thin_provisioning=False,
@@ -57,6 +58,7 @@ SERVICE_STATES_NO_POOLS = {
     'host2@back1': dict(share_backend_name='BBB',
                         total_capacity_gb=256, free_capacity_gb=100,
                         timestamp=None, reserved_percentage=0,
+                        reserved_snapshot_percentage=0,
                         provisioned_capacity_gb=400,
                         max_over_subscription_ratio=2.0,
                         thin_provisioning=True,
@@ -68,6 +70,7 @@ SERVICE_STATES_NO_POOLS = {
     'host2@back2': dict(share_backend_name='CCC',
                         total_capacity_gb=10000, free_capacity_gb=700,
                         timestamp=None, reserved_percentage=0,
+                        reserved_snapshot_percentage=0,
                         provisioned_capacity_gb=50000,
                         max_over_subscription_ratio=20.0,
                         thin_provisioning=True,
@@ -103,6 +106,7 @@ SHARE_SERVICES_WITH_POOLS = [
 SHARE_SERVICE_STATES_WITH_POOLS = {
     'host1@AAA': dict(share_backend_name='AAA',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -112,11 +116,13 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=51,
                                   free_capacity_gb=41,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=10,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
     'host2@BBB': dict(share_backend_name='BBB',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -126,11 +132,13 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=52,
                                   free_capacity_gb=42,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=60,
                                   max_over_subscription_ratio=2.0,
                                   thin_provisioning=True)]),
     'host3@CCC': dict(share_backend_name='CCC',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -140,11 +148,13 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=53,
                                   free_capacity_gb=43,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=20.0,
                                   thin_provisioning=True)]),
     'host4@DDD': dict(share_backend_name='DDD',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -154,6 +164,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=541,
                                   free_capacity_gb=441,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=800,
                                   max_over_subscription_ratio=2.0,
                                   thin_provisioning=True),
@@ -161,11 +172,13 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=542,
                                   free_capacity_gb=442,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=2000,
                                   max_over_subscription_ratio=10.0,
                                   thin_provisioning=True)]),
     'host5@EEE': dict(share_backend_name='EEE',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -175,6 +188,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=551,
                                   free_capacity_gb=451,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False),
@@ -182,11 +196,13 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb=552,
                                   free_capacity_gb=452,
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
     'host6@FFF': dict(share_backend_name='FFF',
                       timestamp=None, reserved_percentage=0,
+                      reserved_snapshot_percentage=0,
                       driver_handles_share_servers=False,
                       snapshot_support=True,
                       create_share_from_snapshot_support=True,
@@ -196,6 +212,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb='unknown',
                                   free_capacity_gb='unknown',
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False),
@@ -203,6 +220,7 @@ SHARE_SERVICE_STATES_WITH_POOLS = {
                                   total_capacity_gb='unknown',
                                   free_capacity_gb='unknown',
                                   reserved_percentage=0,
+                                  reserved_snapshot_percentage=0,
                                   provisioned_capacity_gb=100,
                                   max_over_subscription_ratio=1.0,
                                   thin_provisioning=False)]),
@@ -225,6 +243,7 @@ class FakeHostManager(host_manager.HostManager):
                       'allocated_capacity_gb': 0,
                       'thin_provisioning': False,
                       'reserved_percentage': 10,
+                      'reserved_snapshot_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
@@ -239,6 +258,7 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 2.0,
                       'thin_provisioning': True,
                       'reserved_percentage': 10,
+                      'reserved_snapshot_percentage': 5,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
@@ -253,6 +273,7 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 2.0,
                       'thin_provisioning': [False],
                       'reserved_percentage': 0,
+                      'reserved_snapshot_percentage': 0,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
@@ -265,6 +286,7 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 1.0,
                       'thin_provisioning': [True],
                       'reserved_percentage': 5,
+                      'reserved_snapshot_percentage': 2,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
@@ -279,6 +301,7 @@ class FakeHostManager(host_manager.HostManager):
                       'max_over_subscription_ratio': 1.5,
                       'thin_provisioning': [True, False],
                       'reserved_percentage': 5,
+                      'reserved_snapshot_percentage': 2,
                       'timestamp': None,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
@@ -290,6 +313,7 @@ class FakeHostManager(host_manager.HostManager):
                       'allocated_capacity_gb': 1548,
                       'thin_provisioning': False,
                       'reserved_percentage': 5,
+                      'reserved_snapshot_percentage': 2,
                       'snapshot_support': True,
                       'create_share_from_snapshot_support': True,
                       'timestamp': None,
