@@ -15,7 +15,6 @@
 
 import copy
 import ddt
-import six
 
 from manila import exception
 from manila.share.drivers.dell_emc.common.enas import utils as enas_utils
@@ -302,6 +301,7 @@ class TestConnection(test.TestCase):
         self.assertEqual(
             enas_utils.bytes_to_gb(10000.0), pool['allocated_capacity_gb'])
         self.assertEqual(0, pool['reserved_percentage'])
+        self.assertEqual(0, pool['reserved_snapshot_percentage'])
         self.assertTrue(pool['thin_provisioning'])
         self.assertEqual(
             enas_utils.bytes_to_gb(490000.0), pool['free_capacity_gb'])
@@ -642,9 +642,9 @@ class TestConnection(test.TestCase):
     @res_mock.patch_connection
     def test_get_proto_enum(self, connection):
         self.assertIn('FSSupportedProtocolEnum.CIFS',
-                      six.text_type(connection._get_proto_enum('CIFS')))
+                      str(connection._get_proto_enum('CIFS')))
         self.assertIn('FSSupportedProtocolEnum.NFS',
-                      six.text_type(connection._get_proto_enum('nfs')))
+                      str(connection._get_proto_enum('nfs')))
 
     @res_mock.mock_manila_input
     @res_mock.patch_connection
@@ -886,3 +886,20 @@ class TestConnection(test.TestCase):
         self.assertRaises(exception.ManageInvalidShare,
                           connection.manage_existing_with_server,
                           share, driver_options, share_server)
+
+    @res_mock.mock_manila_input
+    @res_mock.patch_connection
+    def test_get_default_filter_function_disable_report(self, connection,
+                                                        mocked_input):
+        expected = None
+        actual = connection.get_default_filter_function()
+        self.assertEqual(expected, actual)
+
+    @res_mock.mock_manila_input
+    @res_mock.patch_connection
+    def test_get_default_filter_function_enable_report(self, connection,
+                                                       mocked_input):
+        expected = "share.size >= 3"
+        connection.report_default_filter_function = True
+        actual = connection.get_default_filter_function()
+        self.assertEqual(expected, actual)
