@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 
 from manila import exception
@@ -970,6 +971,8 @@ class HitachiHNASTestCase(test.TestCase):
             'total_capacity_gb': 1000,
             'free_capacity_gb': 200,
             'reserved_percentage': driver.CONF.reserved_share_percentage,
+            'reserved_snapshot_percentage':
+                driver.CONF.reserved_share_from_snapshot_percentage,
             'qos': False,
             'thin_provisioning': True,
             'dedupe': True,
