@@ -54,6 +54,7 @@ class TestNexentaNasDriver(test.TestCase):
         self.cfg.nexenta_pool = 'pool1'
         self.cfg.nexenta_dataset_record_size = 131072
         self.cfg.reserved_share_percentage = 0
+        self.cfg.reserved_share_from_snapshot_percentage = 0
         self.cfg.nexenta_folder = 'nfs_share'
         self.cfg.nexenta_user = 'user'
         self.cfg.share_backend_name = 'NexentaStor5'
@@ -391,6 +392,8 @@ class TestNexentaNasDriver(test.TestCase):
                 'max_over_subscription_ratio': 20.0,
                 'reserved_percentage': (
                     self.cfg.reserved_share_percentage),
+                'reserved_snapshot_percentage': (
+                    self.cfg.reserved_share_from_snapshot_percentage),
                 'thin_provisioning': self.cfg.nexenta_thin_provisioning,
             }],
         }
