@@ -215,12 +215,41 @@ class NFSHelperTestCase(test.TestCase):
             [],
             [])
 
-    def test_update_access_delete_invalid_rule(self):
-        delete_rules = [test_generic.get_fake_access_rule(
-            'lala', 'fake_level', access_type='user'), ]
+    @ddt.data({'access_to': 'lala', 'access_type': 'user'},
+              {'access_to': '203.0.113.29'},
+              {'access_to': '2001:0DB8:7d18:c63e:5f0a:871f:83b8:d244',
+               'access_level': 'ro'})
+    @ddt.unpack
+    def test_update_access_delete_invalid_rule(
+            self, access_to, access_level='rw', access_type='ip'):
+        mount_path = '%s:/shares/%s' % (access_to, self.share_name)
+        if access_type == 'ip':
+            self._helper._get_parsed_address_or_cidr = mock.Mock(
+                return_value=access_to)
+            not_found_msg = (
+                "exportfs: Could not find '%s' to unexport.\n" % mount_path
+            )
+            exc = exception.ProcessExecutionError
+            self.mock_object(
+                self._helper,
+                '_ssh_exec',
+                mock.Mock(side_effect=[(0, 0), exc(stderr=not_found_msg)]))
+
+        delete_rules = [
+            test_generic.get_fake_access_rule(access_to,
+                                              access_level,
+                                              access_type),
+        ]
         self.mock_object(self._helper, '_sync_nfs_temp_and_perm_files')
+
         self._helper.update_access(self.server, self.share_name, [],
                                    [], delete_rules)
+
+        if access_type == 'ip':
+            self._helper._ssh_exec.assert_has_calls([
+                mock.call(self.server, ['sudo', 'exportfs']),
+                mock.call(self.server,
+                          ['sudo', 'exportfs', '-u', mount_path])])
         self._helper._sync_nfs_temp_and_perm_files.assert_called_with(
             self.server)
 
@@ -326,13 +355,16 @@ class NFSHelperTestCase(test.TestCase):
     @ddt.data(
         ('/shares/fake_share1\n\t\t1.1.1.10\n'
          '/shares/fake_share2\n\t\t1.1.1.16\n'
+         '/shares/fake_share3\n\t\t<world>\n'
          '/mnt/fake_share1 1.1.1.11', False),
         ('/shares/fake_share_name\n\t\t1.1.1.10\n'
          '/shares/fake_share_name\n\t\t1.1.1.16\n'
+         '/shares/fake_share_name\n\t\t<world>\n'
          '/mnt/fake_share1\n\t\t1.1.1.11', True),
         ('/mnt/fake_share_name\n\t\t1.1.1.11\n'
          '/shares/fake_share_name\n\t\t1.1.1.10\n'
-         '/shares/fake_share_name\n\t\t1.1.1.16\n', True))
+         '/shares/fake_share_name\n\t\t1.1.1.16\n'
+         '/shares/fake_share_name\n\t\t<world>\n', True))
     @ddt.unpack
     def test_disable_access_for_maintenance(self, output, hosts_match):
         fake_maintenance_path = "fake.path"
@@ -368,10 +400,15 @@ class NFSHelperTestCase(test.TestCase):
 
         if hosts_match:
             self._helper._ssh_exec.assert_has_calls([
-                mock.call(self.server, ['sudo', 'exportfs', '-u',
-                                        ':'.join(['1.1.1.10', local_path])]),
-                mock.call(self.server, ['sudo', 'exportfs', '-u',
-                                        ':'.join(['1.1.1.16', local_path])]),
+                mock.call(self.server,
+                          ['sudo', 'exportfs', '-u',
+                           '"{}"'.format(':'.join(['1.1.1.10', local_path]))]),
+                mock.call(self.server,
+                          ['sudo', 'exportfs', '-u',
+                           '"{}"'.format(':'.join(['1.1.1.16', local_path]))]),
+                mock.call(self.server,
+                          ['sudo', 'exportfs', '-u',
+                           '"{}"'.format(':'.join(['<world>', local_path]))]),
             ])
 
         self._helper._sync_nfs_temp_and_perm_files.assert_called_once_with(
@@ -678,11 +715,39 @@ class CIFSHelperIPAccessTestCase(test.TestCase):
             self.server_details, self.share_name)
         self._helper._set_allow_hosts.assert_called_once_with(
             self.server_details, [], self.share_name)
+        kickoff_user_cmd = ['sudo', 'smbstatus', '-S']
+        self._helper._ssh_exec.assert_any_call(
+            self.server_details, kickoff_user_cmd)
         valid_cmd = ['echo', "'test test2'", '|', 'sudo', 'tee',
                      maintenance_path]
-        self._helper._ssh_exec.assert_called_once_with(
+        self._helper._ssh_exec.assert_any_call(
             self.server_details, valid_cmd)
 
+    def test__kick_out_users_success(self):
+        smbstatus_return = """Service      pid     machine       Connected at
+-------------------------------------------------------
+fake_share_name   1001   fake_machine1    Thu Sep 14 14:59:07 2017
+fake_share_name   1002   fake_machine2    Thu Sep 14 14:59:07 2017
+"""
+        self.mock_object(self._helper, '_ssh_exec', mock.Mock(
+            side_effect=[(smbstatus_return, "fake_stderr"), ("fake", "fake")]))
+        self._helper._kick_out_users(self.server_details, self.share_name)
+        self._helper._ssh_exec.assert_any_call(
+            self.server_details, ['sudo', 'smbstatus', '-S'])
+        self._helper._ssh_exec.assert_any_call(
+            self.server_details, ["sudo", "kill", "-15", "1001", "1002"])
+
+    def test__kick_out_users_failed(self):
+        smbstatus_return = """Service      pid     machine       Connected at
+-------------------------------------------------------
+fake line
+"""
+        self.mock_object(self._helper, '_ssh_exec', mock.Mock(
+            return_value=(smbstatus_return, "fake_stderr")))
+        self.assertRaises(exception.ShareBackendException,
+                          self._helper._kick_out_users, self.server_details,
+                          self.share_name)
+
     def test_restore_access_after_maintenance(self):
         fake_maintenance_path = "test.path"
         self.mock_object(self._helper, '_set_allow_hosts')
